import React, { useEffect, useState, memo } from 'react';

import {
  Button,
  Card,
  Col,
  Form,
  Input,
  Row,
  Select,
  Switch,
  Popconfirm,
  Tooltip,
  Space,
} from 'antd';

import { QuestionCircleOutlined } from '@ant-design/icons';

import CustomUpload from '@/components/upload/index';

import { IBanner, EJumpType as Etype } from './types';

const { Option } = Select;

const layout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 16 },
};

interface IProps {
  itemData: IBanner;
  collecrtItem: (itemData: IBanner) => void;
  delItem: (id: string) => void;
}

const MemoCustomUpload = memo(CustomUpload);

const BannerItem: React.FC<IProps> = ({ itemData, collecrtItem, delItem }) => {
  const [form] = Form.useForm();

  const [state, setState] = useState({});

  useEffect(() => {
    form.setFieldsValue({
      ...itemData,
    });

    setState({ ...itemData });
  }, [itemData]);

  // change form
  const changeForm = (key: string, value: any) => {
    form.setFieldsValue({ key: value });

    itemData[key] = value;

    if (key === 'jumpType') {
      form.setFieldsValue({ jumpPath: '' });
      itemData['jumpPath'] = '';
    }

    collecrtItem(itemData);
  };

  return (
    <Card title="配置信息" style={{ marginTop: 20 }}>
      <Form {...layout} form={form} name="control-hooks">
        <Form.Item label="俱乐部" name="roleName">
          <Input disabled />
        </Form.Item>
        <Form.Item label="图片封面" name="imgUrl">
          <MemoCustomUpload
            key={itemData.imgUrl}
            maxCount={1}
            desc="上传图片"
            setCoverFn={(imgUrl) => changeForm('imgUrl', imgUrl)}
            imgUrl={itemData.imgUrl}
          />
        </Form.Item>
        <Form.Item label="跳转类型" name="jumpType">
          <Select
            placeholder="请选择跳转类型"
            allowClear
            onChange={(value: Etype) => changeForm('jumpType', value)}
          >
            <Option value={Etype.h5}>h5</Option>
            <Option value={Etype.miniprogram}>小程序</Option>
          </Select>
        </Form.Item>
        {/* 跳转到h5 */}
        {form.getFieldValue('jumpType') === Etype.h5 && (
          <Form.Item label="跳转地址" name="jumpPath">
            <Input onChange={(e) => changeForm('jumpPath', e.target.value)} />
          </Form.Item>
        )}

        {/* 跳转到小程序 */}
        {form.getFieldValue('jumpType') === Etype.miniprogram && (
          <>
            <Form.Item
              label={
                <span>
                  <Space style={{ marginRight: 4 }}>appid</Space>
                  <Space>
                    <Tooltip title="不填appid, 默认跳转到精英俱乐部">
                      <QuestionCircleOutlined />
                    </Tooltip>
                  </Space>
                </span>
              }
              name="jumpAppId"
            >
              <Input
                placeholder="不填appid, 默认跳转到精英俱乐部"
                onChange={(e) => changeForm('jumpAppId', e.target.value)}
              />
            </Form.Item>

            <Form.Item label="跳转地址" name="jumpPath">
              <Input
                placeholder="不填默认跳转到小程序首页"
                onChange={(e) => changeForm('jumpPath', e.target.value)}
              />
            </Form.Item>
          </>
        )}

        <Form.Item label="是否启用" name="isShow">
          <Switch
            checked={form.getFieldValue('isShow')}
            onChange={(value) => changeForm('isShow', value)}
          />
        </Form.Item>

        <Form.Item label="操作">
          <Popconfirm title="确定要删除当前轮播图吗？" onConfirm={() => delItem(itemData.uid)}>
            <Button>删除</Button>
          </Popconfirm>
        </Form.Item>
      </Form>
    </Card>
  );
};

export default BannerItem;
